# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtRemoteObjects, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtRemoteObjects`

import PySide6.QtRemoteObjects
import PySide6.QtCore
import PySide6.QtNetwork

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QAbstractItemModelReplica(PySide6.QtCore.QAbstractItemModel):

    initialized              : typing.ClassVar[Signal] = ... # initialized()
    def availableRoles(self, /) -> typing.List[int]: ...
    def columnCount(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> int: ...
    def data(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /, role: int = ...) -> typing.Any: ...
    def flags(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> PySide6.QtCore.Qt.ItemFlag: ...
    def hasChildren(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> bool: ...
    def hasData(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, role: int, /) -> bool: ...
    def headerData(self, section: int, orientation: PySide6.QtCore.Qt.Orientation, role: int, /) -> typing.Any: ...
    def index(self, row: int, column: int, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> PySide6.QtCore.QModelIndex: ...
    def isInitialized(self, /) -> bool: ...
    def multiData(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, roleDataSpan: PySide6.QtCore.QModelRoleDataSpan | PySide6.QtCore.QModelRoleData, /) -> None: ...
    @typing.overload
    def parent(self, /) -> PySide6.QtCore.QObject: ...
    @typing.overload
    def parent(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> PySide6.QtCore.QModelIndex: ...
    def roleNames(self, /) -> typing.Dict[int, PySide6.QtCore.QByteArray]: ...
    def rootCacheSize(self, /) -> int: ...
    def rowCount(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> int: ...
    def selectionModel(self, /) -> PySide6.QtCore.QItemSelectionModel: ...
    def setData(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, value: typing.Any, /, role: int = ...) -> bool: ...
    def setRootCacheSize(self, rootCacheSize: int, /) -> None: ...


class QConnectionAbstractServer(PySide6.QtCore.QObject):

    newConnection            : typing.ClassVar[Signal] = ... # newConnection()

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def address(self, /) -> PySide6.QtCore.QUrl: ...
    def close(self, /) -> None: ...
    def configureNewConnection(self, /) -> PySide6.QtRemoteObjects.QtROServerIoDevice: ...
    def hasPendingConnections(self, /) -> bool: ...
    def listen(self, address: PySide6.QtCore.QUrl | str, /) -> bool: ...
    def nextPendingConnection(self, /) -> PySide6.QtRemoteObjects.QtROServerIoDevice: ...
    def serverError(self, /) -> PySide6.QtNetwork.QAbstractSocket.SocketError: ...


class QIntList: ...


class QRemoteObjectAbstractPersistedStore(PySide6.QtCore.QObject):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def restoreProperties(self, repName: str, repSig: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> typing.List[typing.Any]: ...
    def saveProperties(self, repName: str, repSig: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, values: collections.abc.Sequence[typing.Any], /) -> None: ...


class QRemoteObjectDynamicReplica(PySide6.QtRemoteObjects.QRemoteObjectReplica): ...


class QRemoteObjectHost(PySide6.QtRemoteObjects.QRemoteObjectHostBase):

    hostUrlChanged           : typing.ClassVar[Signal] = ... # hostUrlChanged()

    @typing.overload
    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, hostUrl: PySide6.QtCore.QUrl | None = ...) -> None: ...
    @typing.overload
    def __init__(self, address: PySide6.QtCore.QUrl | str, parent: PySide6.QtCore.QObject, /, *, hostUrl: PySide6.QtCore.QUrl | None = ...) -> None: ...
    @typing.overload
    def __init__(self, address: PySide6.QtCore.QUrl | str, /, registryAddress: PySide6.QtCore.QUrl | str = ..., allowedSchemas: PySide6.QtRemoteObjects.QRemoteObjectHostBase.AllowedSchemas = ..., parent: PySide6.QtCore.QObject | None = ..., *, hostUrl: PySide6.QtCore.QUrl | None = ...) -> None: ...

    def hostUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def setHostUrl(self, hostAddress: PySide6.QtCore.QUrl | str, /, allowedSchemas: PySide6.QtRemoteObjects.QRemoteObjectHostBase.AllowedSchemas = ...) -> bool: ...
    @staticmethod
    def setLocalServerOptions(options: PySide6.QtNetwork.QLocalServer.SocketOption, /) -> None: ...


class QRemoteObjectHostBase(PySide6.QtRemoteObjects.QRemoteObjectNode):

    class AllowedSchemas(enum.Enum):

        BuiltInSchemasOnly        = 0x0
        AllowExternalRegistration = 0x1


    def addHostSideConnection(self, ioDevice: PySide6.QtCore.QIODevice, /) -> None: ...
    def disableRemoting(self, remoteObject: PySide6.QtCore.QObject, /) -> bool: ...
    @typing.overload
    def enableRemoting(self, model: PySide6.QtCore.QAbstractItemModel, name: str, roles: collections.abc.Sequence[int], /, selectionModel: PySide6.QtCore.QItemSelectionModel | None = ...) -> bool: ...
    @typing.overload
    def enableRemoting(self, object: PySide6.QtCore.QObject, /, name: str = ...) -> bool: ...
    def hostUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def proxy(self, registryUrl: PySide6.QtCore.QUrl | str, /, hostUrl: PySide6.QtCore.QUrl | str = ...) -> bool: ...
    def reverseProxy(self, /) -> bool: ...
    def setHostUrl(self, hostAddress: PySide6.QtCore.QUrl | str, /, allowedSchemas: PySide6.QtRemoteObjects.QRemoteObjectHostBase.AllowedSchemas = ...) -> bool: ...
    def setName(self, name: str, /) -> None: ...


class QRemoteObjectNode(PySide6.QtCore.QObject):

    error                    : typing.ClassVar[Signal] = ... # error(QRemoteObjectNode::ErrorCode)
    heartbeatIntervalChanged : typing.ClassVar[Signal] = ... # heartbeatIntervalChanged(int)
    remoteObjectAdded        : typing.ClassVar[Signal] = ... # remoteObjectAdded(QRemoteObjectSourceLocation)
    remoteObjectRemoved      : typing.ClassVar[Signal] = ... # remoteObjectRemoved(QRemoteObjectSourceLocation)

    class ErrorCode(enum.Enum):

        NoError                   = 0x0
        RegistryNotAcquired       = 0x1
        RegistryAlreadyHosted     = 0x2
        NodeIsNoServer            = 0x3
        ServerAlreadyCreated      = 0x4
        UnintendedRegistryHosting = 0x5
        OperationNotValidOnClientNode = 0x6
        SourceNotRegistered       = 0x7
        MissingObjectName         = 0x8
        HostUrlInvalid            = 0x9
        ProtocolMismatch          = 0xa
        ListenFailed              = 0xb
        SocketAccessError         = 0xc


    @typing.overload
    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, registryUrl: PySide6.QtCore.QUrl | None = ..., persistedStore: PySide6.QtRemoteObjects.QRemoteObjectAbstractPersistedStore | None = ..., heartbeatInterval: int | None = ...) -> None: ...
    @typing.overload
    def __init__(self, registryAddress: PySide6.QtCore.QUrl | str, /, parent: PySide6.QtCore.QObject | None = ..., *, registryUrl: PySide6.QtCore.QUrl | None = ..., persistedStore: PySide6.QtRemoteObjects.QRemoteObjectAbstractPersistedStore | None = ..., heartbeatInterval: int | None = ...) -> None: ...

    def acquire(self, arg__1: type, /, name: object | None = ...) -> type: ...
    def acquireDynamic(self, name: str, /) -> PySide6.QtRemoteObjects.QRemoteObjectDynamicReplica: ...
    def acquireModel(self, name: str, /, action: PySide6.QtRemoteObjects.QtRemoteObjects.InitialAction = ..., rolesHint: collections.abc.Sequence[int] = ...) -> PySide6.QtRemoteObjects.QAbstractItemModelReplica: ...
    def addClientSideConnection(self, ioDevice: PySide6.QtCore.QIODevice, /) -> None: ...
    def connectToNode(self, address: PySide6.QtCore.QUrl | str, /) -> bool: ...
    def heartbeatInterval(self, /) -> int: ...
    def instances(self, typeName: str, /) -> typing.List[str]: ...
    def lastError(self, /) -> PySide6.QtRemoteObjects.QRemoteObjectNode.ErrorCode: ...
    def persistedStore(self, /) -> PySide6.QtRemoteObjects.QRemoteObjectAbstractPersistedStore: ...
    def registry(self, /) -> PySide6.QtRemoteObjects.QRemoteObjectRegistry: ...
    def registryUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def setHeartbeatInterval(self, interval: int, /) -> None: ...
    def setName(self, name: str, /) -> None: ...
    def setPersistedStore(self, persistedStore: PySide6.QtRemoteObjects.QRemoteObjectAbstractPersistedStore, /) -> None: ...
    def setRegistryUrl(self, registryAddress: PySide6.QtCore.QUrl | str, /) -> bool: ...
    def timerEvent(self, arg__1: PySide6.QtCore.QTimerEvent, /) -> None: ...
    def waitForRegistry(self, /, timeout: int = ...) -> bool: ...


class QRemoteObjectPendingCall(Shiboken.Object):

    class Error(enum.Enum):

        NoError                   = 0x0
        InvalidMessage            = 0x1


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtRemoteObjects.QRemoteObjectPendingCall, /) -> None: ...

    def error(self, /) -> PySide6.QtRemoteObjects.QRemoteObjectPendingCall.Error: ...
    @staticmethod
    def fromCompletedCall(returnValue: typing.Any, /) -> PySide6.QtRemoteObjects.QRemoteObjectPendingCall: ...
    def isFinished(self, /) -> bool: ...
    def returnValue(self, /) -> typing.Any: ...
    def waitForFinished(self, /, timeout: int = ...) -> bool: ...


class QRemoteObjectPendingCallWatcher(PySide6.QtCore.QObject, PySide6.QtRemoteObjects.QRemoteObjectPendingCall):

    finished                 : typing.ClassVar[Signal] = ... # finished(QRemoteObjectPendingCallWatcher*)

    def __init__(self, call: PySide6.QtRemoteObjects.QRemoteObjectPendingCall, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def isFinished(self, /) -> bool: ...
    def waitForFinished(self, /) -> None: ...


class QRemoteObjectRegistry(PySide6.QtRemoteObjects.QRemoteObjectReplica):

    remoteObjectAdded        : typing.ClassVar[Signal] = ... # remoteObjectAdded(QRemoteObjectSourceLocation)
    remoteObjectRemoved      : typing.ClassVar[Signal] = ... # remoteObjectRemoved(QRemoteObjectSourceLocation)
    def addSource(self, entry: typing.Tuple[str, PySide6.QtRemoteObjects.QRemoteObjectSourceLocationInfo], /) -> None: ...
    def initialize(self, /) -> None: ...
    def pushToRegistryIfNeeded(self, /) -> None: ...
    @staticmethod
    def registerMetatypes() -> None: ...
    def removeSource(self, entry: typing.Tuple[str, PySide6.QtRemoteObjects.QRemoteObjectSourceLocationInfo], /) -> None: ...
    def sourceLocations(self, /) -> typing.Dict[str, PySide6.QtRemoteObjects.QRemoteObjectSourceLocationInfo]: ...


class QRemoteObjectRegistryHost(PySide6.QtRemoteObjects.QRemoteObjectHostBase):

    def __init__(self, /, registryAddress: PySide6.QtCore.QUrl | str = ..., parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def setRegistryUrl(self, registryUrl: PySide6.QtCore.QUrl | str, /) -> bool: ...


class QRemoteObjectReplica(PySide6.QtCore.QObject):

    initialized              : typing.ClassVar[Signal] = ... # initialized()
    notified                 : typing.ClassVar[Signal] = ... # notified()
    stateChanged             : typing.ClassVar[Signal] = ... # stateChanged(State,State)

    class ConstructorType(enum.IntEnum):

        DefaultConstructor        = 0x0
        ConstructWithNode         = 0x1

    class State(enum.Enum):

        Uninitialized             = 0x0
        Default                   = 0x1
        Valid                     = 0x2
        Suspect                   = 0x3
        SignatureMismatch         = 0x4


    def __init__(self, /, t: PySide6.QtRemoteObjects.QRemoteObjectReplica.ConstructorType = ..., *, node: PySide6.QtRemoteObjects.QRemoteObjectNode | None = ..., state: PySide6.QtRemoteObjects.QRemoteObjectReplica.State | None = ...) -> None: ...

    def initialize(self, /) -> None: ...
    def initializeNode(self, node: PySide6.QtRemoteObjects.QRemoteObjectNode, /, name: str = ...) -> None: ...
    def isInitialized(self, /) -> bool: ...
    def isReplicaValid(self, /) -> bool: ...
    def node(self, /) -> PySide6.QtRemoteObjects.QRemoteObjectNode: ...
    def persistProperties(self, repName: str, repSig: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, props: collections.abc.Sequence[typing.Any], /) -> None: ...
    def propAsVariant(self, i: int, /) -> typing.Any: ...
    def retrieveProperties(self, repName: str, repSig: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> typing.List[typing.Any]: ...
    def send(self, call: PySide6.QtCore.QMetaObject.Call, index: int, args: collections.abc.Sequence[typing.Any], /) -> None: ...
    def sendWithReply(self, call: PySide6.QtCore.QMetaObject.Call, index: int, args: collections.abc.Sequence[typing.Any], /) -> PySide6.QtRemoteObjects.QRemoteObjectPendingCall: ...
    def setChild(self, i: int, arg__2: typing.Any, /) -> None: ...
    def setNode(self, node: PySide6.QtRemoteObjects.QRemoteObjectNode, /) -> None: ...
    def state(self, /) -> PySide6.QtRemoteObjects.QRemoteObjectReplica.State: ...
    def waitForSource(self, /, timeout: int = ...) -> bool: ...


class QRemoteObjectSettingsStore(PySide6.QtRemoteObjects.QRemoteObjectAbstractPersistedStore):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def restoreProperties(self, repName: str, repSig: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> typing.List[typing.Any]: ...
    def saveProperties(self, repName: str, repSig: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, values: collections.abc.Sequence[typing.Any], /) -> None: ...


class QRemoteObjectSourceLocationInfo(Shiboken.Object):

    hostUrl                   = ...  # type: PySide6.QtCore.QUrl
    typeName                  = ...  # type: str

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QRemoteObjectSourceLocationInfo: PySide6.QtRemoteObjects.QRemoteObjectSourceLocationInfo, /) -> None: ...
    @typing.overload
    def __init__(self, typeName_: str, hostUrl_: PySide6.QtCore.QUrl | str, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, other: PySide6.QtRemoteObjects.QRemoteObjectSourceLocationInfo, /) -> bool: ...
    def __lshift__(self, stream: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def __ne__(self, other: PySide6.QtRemoteObjects.QRemoteObjectSourceLocationInfo, /) -> bool: ...
    def __repr__(self, /) -> str: ...
    def __rshift__(self, stream: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...


class QtROClientFactory(Shiboken.Object):
    def create(self, url: PySide6.QtCore.QUrl | str, /, parent: PySide6.QtCore.QObject | None = ...) -> PySide6.QtRemoteObjects.QtROClientIoDevice: ...
    @staticmethod
    def instance() -> PySide6.QtRemoteObjects.QtROClientFactory: ...
    def isValid(self, url: PySide6.QtCore.QUrl | str, /) -> bool: ...


class QtROClientIoDevice(PySide6.QtRemoteObjects.QtROIoDeviceBase):

    setError                 : typing.ClassVar[Signal] = ... # setError(QRemoteObjectNode::ErrorCode)
    shouldReconnect          : typing.ClassVar[Signal] = ... # shouldReconnect(QtROClientIoDevice*)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def connectToServer(self, /) -> None: ...
    def deviceType(self, /) -> str: ...
    def disconnectFromServer(self, /) -> None: ...
    def doDisconnectFromServer(self, /) -> None: ...
    def setUrl(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QtROIoDeviceBase(PySide6.QtCore.QObject):

    disconnected             : typing.ClassVar[Signal] = ... # disconnected()
    readyRead                : typing.ClassVar[Signal] = ... # readyRead()

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def addSource(self, arg__1: str, /) -> None: ...
    def bytesAvailable(self, /) -> int: ...
    def close(self, /) -> None: ...
    def connection(self, /) -> PySide6.QtCore.QIODevice: ...
    def deviceType(self, /) -> str: ...
    def doClose(self, /) -> None: ...
    def initializeDataStream(self, /) -> None: ...
    def isClosing(self, /) -> bool: ...
    def isOpen(self, /) -> bool: ...
    def read(self, arg__1: PySide6.QtRemoteObjects.QtRemoteObjects.QRemoteObjectPacketTypeEnum, arg__2: str, /) -> bool: ...
    def remoteObjects(self, /) -> typing.Set[str]: ...
    def removeSource(self, arg__1: str, /) -> None: ...
    @typing.overload
    def write(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    @typing.overload
    def write(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, arg__2: int, /) -> None: ...


class QtROServerFactory(Shiboken.Object):
    def create(self, url: PySide6.QtCore.QUrl | str, /, parent: PySide6.QtCore.QObject | None = ...) -> PySide6.QtRemoteObjects.QConnectionAbstractServer: ...
    @staticmethod
    def instance() -> PySide6.QtRemoteObjects.QtROServerFactory: ...
    def isValid(self, url: PySide6.QtCore.QUrl | str, /) -> bool: ...


class QtROServerIoDevice(PySide6.QtRemoteObjects.QtROIoDeviceBase):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def deviceType(self, /) -> str: ...


class QtRemoteObjects(Shiboken.Object):

    class InitialAction(enum.Enum):

        FetchRootSize             = 0x0
        PrefetchData              = 0x1

    class QRemoteObjectPacketTypeEnum(enum.Enum):

        Invalid                   = 0x0
        Handshake                 = 0x1
        InitPacket                = 0x2
        InitDynamicPacket         = 0x3
        AddObject                 = 0x4
        RemoveObject              = 0x5
        InvokePacket              = 0x6
        InvokeReplyPacket         = 0x7
        PropertyChangePacket      = 0x8
        ObjectList                = 0x9
        Ping                      = 0xa
        Pong                      = 0xb


    @typing.overload
    @staticmethod
    def copyStoredProperties(mo: PySide6.QtCore.QMetaObject, src: PySide6.QtCore.QDataStream, dst: int, /) -> None: ...
    @typing.overload
    @staticmethod
    def copyStoredProperties(mo: PySide6.QtCore.QMetaObject, src: int, dst: PySide6.QtCore.QDataStream, /) -> None: ...
    @typing.overload
    @staticmethod
    def copyStoredProperties(mo: PySide6.QtCore.QMetaObject, src: int, dst: int, /) -> None: ...


class RepFile:

    pod                       = ...  # type: typing.Any
    replica                   = ...  # type: typing.Any
    source                    = ...  # type: typing.Any

    def __init__(self, content: str, /) -> None: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtSpatialAudio, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtSpatialAudio`

import PySide6.QtSpatialAudio
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtMultimedia

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal


class QAmbientSound(PySide6.QtCore.QObject):

    autoPlayChanged          : typing.ClassVar[Signal] = ... # autoPlayChanged()
    loopsChanged             : typing.ClassVar[Signal] = ... # loopsChanged()
    sourceChanged            : typing.ClassVar[Signal] = ... # sourceChanged()
    volumeChanged            : typing.ClassVar[Signal] = ... # volumeChanged()

    class Loops(enum.IntEnum):

        Infinite                  = -1
        Once                      = 0x1


    def __init__(self, engine: PySide6.QtSpatialAudio.QAudioEngine, /, *, source: PySide6.QtCore.QUrl | None = ..., volume: float | None = ..., loops: int | None = ..., autoPlay: bool | None = ...) -> None: ...

    def autoPlay(self, /) -> bool: ...
    def engine(self, /) -> PySide6.QtSpatialAudio.QAudioEngine: ...
    def loops(self, /) -> int: ...
    def pause(self, /) -> None: ...
    def play(self, /) -> None: ...
    def setAutoPlay(self, autoPlay: bool, /) -> None: ...
    def setLoops(self, loops: int, /) -> None: ...
    def setSource(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    def setVolume(self, volume: float, /) -> None: ...
    def source(self, /) -> PySide6.QtCore.QUrl: ...
    def stop(self, /) -> None: ...
    def volume(self, /) -> float: ...


class QAudioEngine(PySide6.QtCore.QObject):

    distanceScaleChanged     : typing.ClassVar[Signal] = ... # distanceScaleChanged()
    masterVolumeChanged      : typing.ClassVar[Signal] = ... # masterVolumeChanged()
    outputDeviceChanged      : typing.ClassVar[Signal] = ... # outputDeviceChanged()
    outputModeChanged        : typing.ClassVar[Signal] = ... # outputModeChanged()
    pausedChanged            : typing.ClassVar[Signal] = ... # pausedChanged()

    class OutputMode(enum.Enum):

        Surround                  = 0x0
        Stereo                    = 0x1
        Headphone                 = 0x2


    @typing.overload
    def __init__(self, parent: PySide6.QtCore.QObject, /, *, outputMode: PySide6.QtSpatialAudio.QAudioEngine.OutputMode | None = ..., outputDevice: PySide6.QtMultimedia.QAudioDevice | None = ..., masterVolume: float | None = ..., paused: bool | None = ..., distanceScale: float | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, outputMode: PySide6.QtSpatialAudio.QAudioEngine.OutputMode | None = ..., outputDevice: PySide6.QtMultimedia.QAudioDevice | None = ..., masterVolume: float | None = ..., paused: bool | None = ..., distanceScale: float | None = ...) -> None: ...
    @typing.overload
    def __init__(self, sampleRate: int, /, parent: PySide6.QtCore.QObject | None = ..., *, outputMode: PySide6.QtSpatialAudio.QAudioEngine.OutputMode | None = ..., outputDevice: PySide6.QtMultimedia.QAudioDevice | None = ..., masterVolume: float | None = ..., paused: bool | None = ..., distanceScale: float | None = ...) -> None: ...

    def distanceScale(self, /) -> float: ...
    def masterVolume(self, /) -> float: ...
    def outputDevice(self, /) -> PySide6.QtMultimedia.QAudioDevice: ...
    def outputMode(self, /) -> PySide6.QtSpatialAudio.QAudioEngine.OutputMode: ...
    def pause(self, /) -> None: ...
    def paused(self, /) -> bool: ...
    def resume(self, /) -> None: ...
    def roomEffectsEnabled(self, /) -> bool: ...
    def sampleRate(self, /) -> int: ...
    def setDistanceScale(self, scale: float, /) -> None: ...
    def setMasterVolume(self, volume: float, /) -> None: ...
    def setOutputDevice(self, device: PySide6.QtMultimedia.QAudioDevice, /) -> None: ...
    def setOutputMode(self, mode: PySide6.QtSpatialAudio.QAudioEngine.OutputMode, /) -> None: ...
    def setPaused(self, paused: bool, /) -> None: ...
    def setRoomEffectsEnabled(self, enabled: bool, /) -> None: ...
    def start(self, /) -> None: ...
    def stop(self, /) -> None: ...


class QAudioListener(PySide6.QtCore.QObject):

    def __init__(self, engine: PySide6.QtSpatialAudio.QAudioEngine, /) -> None: ...

    def engine(self, /) -> PySide6.QtSpatialAudio.QAudioEngine: ...
    def position(self, /) -> PySide6.QtGui.QVector3D: ...
    def rotation(self, /) -> PySide6.QtGui.QQuaternion: ...
    def setPosition(self, pos: PySide6.QtGui.QVector3D, /) -> None: ...
    def setRotation(self, q: PySide6.QtGui.QQuaternion, /) -> None: ...


class QAudioRoom(PySide6.QtCore.QObject):

    dimensionsChanged        : typing.ClassVar[Signal] = ... # dimensionsChanged()
    positionChanged          : typing.ClassVar[Signal] = ... # positionChanged()
    reflectionGainChanged    : typing.ClassVar[Signal] = ... # reflectionGainChanged()
    reverbBrightnessChanged  : typing.ClassVar[Signal] = ... # reverbBrightnessChanged()
    reverbGainChanged        : typing.ClassVar[Signal] = ... # reverbGainChanged()
    reverbTimeChanged        : typing.ClassVar[Signal] = ... # reverbTimeChanged()
    rotationChanged          : typing.ClassVar[Signal] = ... # rotationChanged()
    wallsChanged             : typing.ClassVar[Signal] = ... # wallsChanged()

    class Material(enum.Enum):

        Transparent               = 0x0
        AcousticCeilingTiles      = 0x1
        BrickBare                 = 0x2
        BrickPainted              = 0x3
        ConcreteBlockCoarse       = 0x4
        ConcreteBlockPainted      = 0x5
        CurtainHeavy              = 0x6
        FiberGlassInsulation      = 0x7
        GlassThin                 = 0x8
        GlassThick                = 0x9
        Grass                     = 0xa
        LinoleumOnConcrete        = 0xb
        Marble                    = 0xc
        Metal                     = 0xd
        ParquetOnConcrete         = 0xe
        PlasterRough              = 0xf
        PlasterSmooth             = 0x10
        PlywoodPanel              = 0x11
        PolishedConcreteOrTile    = 0x12
        Sheetrock                 = 0x13
        WaterOrIceSurface         = 0x14
        WoodCeiling               = 0x15
        WoodPanel                 = 0x16
        UniformMaterial           = 0x17

    class Wall(enum.Enum):

        LeftWall                  = 0x0
        RightWall                 = 0x1
        Floor                     = 0x2
        Ceiling                   = 0x3
        FrontWall                 = 0x4
        BackWall                  = 0x5


    def __init__(self, engine: PySide6.QtSpatialAudio.QAudioEngine, /, *, position: PySide6.QtGui.QVector3D | None = ..., dimensions: PySide6.QtGui.QVector3D | None = ..., rotation: PySide6.QtGui.QQuaternion | None = ..., reflectionGain: float | None = ..., reverbGain: float | None = ..., reverbTime: float | None = ..., reverbBrightness: float | None = ...) -> None: ...

    def dimensions(self, /) -> PySide6.QtGui.QVector3D: ...
    def position(self, /) -> PySide6.QtGui.QVector3D: ...
    def reflectionGain(self, /) -> float: ...
    def reverbBrightness(self, /) -> float: ...
    def reverbGain(self, /) -> float: ...
    def reverbTime(self, /) -> float: ...
    def rotation(self, /) -> PySide6.QtGui.QQuaternion: ...
    def setDimensions(self, dim: PySide6.QtGui.QVector3D, /) -> None: ...
    def setPosition(self, pos: PySide6.QtGui.QVector3D, /) -> None: ...
    def setReflectionGain(self, factor: float, /) -> None: ...
    def setReverbBrightness(self, factor: float, /) -> None: ...
    def setReverbGain(self, factor: float, /) -> None: ...
    def setReverbTime(self, factor: float, /) -> None: ...
    def setRotation(self, q: PySide6.QtGui.QQuaternion, /) -> None: ...
    def setWallMaterial(self, wall: PySide6.QtSpatialAudio.QAudioRoom.Wall, material: PySide6.QtSpatialAudio.QAudioRoom.Material, /) -> None: ...
    def wallMaterial(self, wall: PySide6.QtSpatialAudio.QAudioRoom.Wall, /) -> PySide6.QtSpatialAudio.QAudioRoom.Material: ...


class QIntList: ...


class QSpatialSound(PySide6.QtCore.QObject):

    autoPlayChanged          : typing.ClassVar[Signal] = ... # autoPlayChanged()
    directivityChanged       : typing.ClassVar[Signal] = ... # directivityChanged()
    directivityOrderChanged  : typing.ClassVar[Signal] = ... # directivityOrderChanged()
    distanceCutoffChanged    : typing.ClassVar[Signal] = ... # distanceCutoffChanged()
    distanceModelChanged     : typing.ClassVar[Signal] = ... # distanceModelChanged()
    loopsChanged             : typing.ClassVar[Signal] = ... # loopsChanged()
    manualAttenuationChanged : typing.ClassVar[Signal] = ... # manualAttenuationChanged()
    nearFieldGainChanged     : typing.ClassVar[Signal] = ... # nearFieldGainChanged()
    occlusionIntensityChanged: typing.ClassVar[Signal] = ... # occlusionIntensityChanged()
    positionChanged          : typing.ClassVar[Signal] = ... # positionChanged()
    rotationChanged          : typing.ClassVar[Signal] = ... # rotationChanged()
    sizeChanged              : typing.ClassVar[Signal] = ... # sizeChanged()
    sourceChanged            : typing.ClassVar[Signal] = ... # sourceChanged()
    volumeChanged            : typing.ClassVar[Signal] = ... # volumeChanged()

    class DistanceModel(enum.Enum):

        Logarithmic               = 0x0
        Linear                    = 0x1
        ManualAttenuation         = 0x2

    class Loops(enum.IntEnum):

        Infinite                  = -1
        Once                      = 0x1


    def __init__(self, engine: PySide6.QtSpatialAudio.QAudioEngine, /, *, source: PySide6.QtCore.QUrl | None = ..., position: PySide6.QtGui.QVector3D | None = ..., rotation: PySide6.QtGui.QQuaternion | None = ..., volume: float | None = ..., distanceModel: PySide6.QtSpatialAudio.QSpatialSound.DistanceModel | None = ..., size: float | None = ..., distanceCutoff: float | None = ..., manualAttenuation: float | None = ..., occlusionIntensity: float | None = ..., directivity: float | None = ..., directivityOrder: float | None = ..., nearFieldGain: float | None = ..., loops: int | None = ..., autoPlay: bool | None = ...) -> None: ...

    def autoPlay(self, /) -> bool: ...
    def directivity(self, /) -> float: ...
    def directivityOrder(self, /) -> float: ...
    def distanceCutoff(self, /) -> float: ...
    def distanceModel(self, /) -> PySide6.QtSpatialAudio.QSpatialSound.DistanceModel: ...
    def engine(self, /) -> PySide6.QtSpatialAudio.QAudioEngine: ...
    def loops(self, /) -> int: ...
    def manualAttenuation(self, /) -> float: ...
    def nearFieldGain(self, /) -> float: ...
    def occlusionIntensity(self, /) -> float: ...
    def pause(self, /) -> None: ...
    def play(self, /) -> None: ...
    def position(self, /) -> PySide6.QtGui.QVector3D: ...
    def rotation(self, /) -> PySide6.QtGui.QQuaternion: ...
    def setAutoPlay(self, autoPlay: bool, /) -> None: ...
    def setDirectivity(self, alpha: float, /) -> None: ...
    def setDirectivityOrder(self, alpha: float, /) -> None: ...
    def setDistanceCutoff(self, cutoff: float, /) -> None: ...
    def setDistanceModel(self, model: PySide6.QtSpatialAudio.QSpatialSound.DistanceModel, /) -> None: ...
    def setLoops(self, loops: int, /) -> None: ...
    def setManualAttenuation(self, attenuation: float, /) -> None: ...
    def setNearFieldGain(self, gain: float, /) -> None: ...
    def setOcclusionIntensity(self, occlusion: float, /) -> None: ...
    def setPosition(self, pos: PySide6.QtGui.QVector3D, /) -> None: ...
    def setRotation(self, q: PySide6.QtGui.QQuaternion, /) -> None: ...
    def setSize(self, size: float, /) -> None: ...
    def setSource(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    def setVolume(self, volume: float, /) -> None: ...
    def size(self, /) -> float: ...
    def source(self, /) -> PySide6.QtCore.QUrl: ...
    def stop(self, /) -> None: ...
    def volume(self, /) -> float: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtWebView, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtWebView`

import PySide6.QtWebView
import PySide6.QtCore
import PySide6.QtGui

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class QWebView(PySide6.QtGui.QWindow):

    cookieAdded              : typing.ClassVar[Signal] = ... # cookieAdded(QString,QString)
    cookieRemoved            : typing.ClassVar[Signal] = ... # cookieRemoved(QString,QString)
    httpUserAgentStringChanged: typing.ClassVar[Signal] = ... # httpUserAgentStringChanged(QString)
    loadProgressChanged      : typing.ClassVar[Signal] = ... # loadProgressChanged(int)
    loadingChanged           : typing.ClassVar[Signal] = ... # loadingChanged(QWebViewLoadingInfo)
    titleChanged             : typing.ClassVar[Signal] = ... # titleChanged(QString)
    urlChanged               : typing.ClassVar[Signal] = ... # urlChanged(QUrl)

    @typing.overload
    def __init__(self, parent: PySide6.QtGui.QWindow, /, *, httpUserAgentString: str | None = ..., url: PySide6.QtCore.QUrl | None = ..., loading: bool | None = ..., loadProgress: int | None = ..., title: str | None = ..., settings: PySide6.QtWebView.QWebViewSettings | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, screen: PySide6.QtGui.QScreen | None = ..., *, httpUserAgentString: str | None = ..., url: PySide6.QtCore.QUrl | None = ..., loading: bool | None = ..., loadProgress: int | None = ..., title: str | None = ..., settings: PySide6.QtWebView.QWebViewSettings | None = ...) -> None: ...

    def canGoBack(self, /) -> bool: ...
    def canGoForward(self, /) -> bool: ...
    def deleteAllCookies(self, /) -> None: ...
    def deleteCookie(self, domain: str, name: str, /) -> None: ...
    def event(self, arg__1: PySide6.QtCore.QEvent, /) -> bool: ...
    def goBack(self, /) -> None: ...
    def goForward(self, /) -> None: ...
    def httpUserAgentString(self, /) -> str: ...
    def isLoading(self, /) -> bool: ...
    def loadHtml(self, html: str, /, baseUrl: PySide6.QtCore.QUrl | str = ...) -> None: ...
    def loadProgress(self, /) -> int: ...
    def reload(self, /) -> None: ...
    def runJavaScript(self, scriptSource: str, resultCallback: collections.abc.Callable[..., typing.Any], /) -> None: ...
    def setCookie(self, domain: str, name: str, value: str, /) -> None: ...
    def setHttpUserAgentString(self, httpUserAgent: str, /) -> None: ...
    def setUrl(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    def settings(self, /) -> PySide6.QtWebView.QWebViewSettings: ...
    def stop(self, /) -> None: ...
    def title(self, /) -> str: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QWebViewLoadingInfo(Shiboken.Object):

    class LoadStatus(enum.Enum):

        Started                   = 0x0
        Stopped                   = 0x1
        Succeeded                 = 0x2
        Failed                    = 0x3


    @typing.overload
    def __init__(self, other: PySide6.QtWebView.QWebViewLoadingInfo, /, *, url: PySide6.QtCore.QUrl | None = ..., status: PySide6.QtWebView.QWebViewLoadingInfo.LoadStatus | None = ..., errorString: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, url: PySide6.QtCore.QUrl | None = ..., status: PySide6.QtWebView.QWebViewLoadingInfo.LoadStatus | None = ..., errorString: str | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def errorString(self, /) -> str: ...
    def status(self, /) -> PySide6.QtWebView.QWebViewLoadingInfo.LoadStatus: ...
    def swap(self, other: PySide6.QtWebView.QWebViewLoadingInfo, /) -> None: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QWebViewSettings(Shiboken.Object):

    class WebAttribute(enum.Enum):

        LocalStorageEnabled       = 0x0
        JavaScriptEnabled         = 0x1
        AllowFileAccess           = 0x2
        LocalContentCanAccessFileUrls = 0x3


    def setAttribute(self, attribute: PySide6.QtWebView.QWebViewSettings.WebAttribute, value: bool, /) -> None: ...
    def testAttribute(self, attribute: PySide6.QtWebView.QWebViewSettings.WebAttribute, /) -> bool: ...


class QtWebView(Shiboken.Object):
    @staticmethod
    def initialize() -> None: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtSql, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtSql`

import PySide6.QtSql
import PySide6.QtCore
import PySide6.QtWidgets

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class QSql(Shiboken.Object):

    class Location(enum.Enum):

        AfterLastRow              = -2
        BeforeFirstRow            = -1

    class NumericalPrecisionPolicy(enum.Enum):

        HighPrecision             = 0x0
        LowPrecisionInt32         = 0x1
        LowPrecisionInt64         = 0x2
        LowPrecisionDouble        = 0x4

    class ParamTypeFlag(enum.Flag):

        In                        = 0x1
        Out                       = 0x2
        InOut                     = 0x3
        Binary                    = 0x4

    class TableType(enum.Enum):

        Tables                    = 0x1
        SystemTables              = 0x2
        Views                     = 0x4
        AllTables                 = 0xff


class QSqlDatabase(Shiboken.Object):

    @typing.overload
    def __init__(self, driver: PySide6.QtSql.QSqlDriver, /, *, numericalPrecisionPolicy: PySide6.QtSql.QSql.NumericalPrecisionPolicy | None = ...) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtSql.QSqlDatabase, /, *, numericalPrecisionPolicy: PySide6.QtSql.QSql.NumericalPrecisionPolicy | None = ...) -> None: ...
    @typing.overload
    def __init__(self, type: str, /, *, numericalPrecisionPolicy: PySide6.QtSql.QSql.NumericalPrecisionPolicy | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, numericalPrecisionPolicy: PySide6.QtSql.QSql.NumericalPrecisionPolicy | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __repr__(self, /) -> str: ...
    @typing.overload
    @staticmethod
    def addDatabase(driver: PySide6.QtSql.QSqlDriver, /, connectionName: str = ...) -> PySide6.QtSql.QSqlDatabase: ...
    @typing.overload
    @staticmethod
    def addDatabase(type: str, /, connectionName: str = ...) -> PySide6.QtSql.QSqlDatabase: ...
    @typing.overload
    @staticmethod
    def cloneDatabase(other: PySide6.QtSql.QSqlDatabase, connectionName: str, /) -> PySide6.QtSql.QSqlDatabase: ...
    @typing.overload
    @staticmethod
    def cloneDatabase(other: str, connectionName: str, /) -> PySide6.QtSql.QSqlDatabase: ...
    def close(self, /) -> None: ...
    def commit(self, /) -> bool: ...
    def connectOptions(self, /) -> str: ...
    def connectionName(self, /) -> str: ...
    @staticmethod
    def connectionNames() -> typing.List[str]: ...
    @staticmethod
    def contains(connectionName: str = ...) -> bool: ...
    @staticmethod
    def database(connectionName: str = ..., open: bool = ...) -> PySide6.QtSql.QSqlDatabase: ...
    def databaseName(self, /) -> str: ...
    def driver(self, /) -> PySide6.QtSql.QSqlDriver: ...
    def driverName(self, /) -> str: ...
    @staticmethod
    def drivers() -> typing.List[str]: ...
    def exec(self, /, query: str = ...) -> PySide6.QtSql.QSqlQuery: ...
    def exec_(self, /, query: str = ...) -> PySide6.QtSql.QSqlQuery: ...
    def hostName(self, /) -> str: ...
    @staticmethod
    def isDriverAvailable(name: str, /) -> bool: ...
    def isOpen(self, /) -> bool: ...
    def isOpenError(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def lastError(self, /) -> PySide6.QtSql.QSqlError: ...
    def moveToThread(self, targetThread: PySide6.QtCore.QThread, /) -> bool: ...
    def numericalPrecisionPolicy(self, /) -> PySide6.QtSql.QSql.NumericalPrecisionPolicy: ...
    @typing.overload
    def open(self, /) -> bool: ...
    @typing.overload
    def open(self, user: str, password: str, /) -> bool: ...
    def password(self, /) -> str: ...
    def port(self, /) -> int: ...
    def primaryIndex(self, tablename: str, /) -> PySide6.QtSql.QSqlIndex: ...
    def record(self, tablename: str, /) -> PySide6.QtSql.QSqlRecord: ...
    @staticmethod
    def registerSqlDriver(name: str, creator: PySide6.QtSql.QSqlDriverCreatorBase, /) -> None: ...
    @staticmethod
    def removeDatabase(connectionName: str, /) -> None: ...
    def rollback(self, /) -> bool: ...
    def setConnectOptions(self, /, options: str = ...) -> None: ...
    def setDatabaseName(self, name: str, /) -> None: ...
    def setHostName(self, host: str, /) -> None: ...
    def setNumericalPrecisionPolicy(self, precisionPolicy: PySide6.QtSql.QSql.NumericalPrecisionPolicy, /) -> None: ...
    def setPassword(self, password: str, /) -> None: ...
    def setPort(self, p: int, /) -> None: ...
    def setUserName(self, name: str, /) -> None: ...
    def tables(self, /, type: PySide6.QtSql.QSql.TableType = ...) -> typing.List[str]: ...
    def thread(self, /) -> PySide6.QtCore.QThread: ...
    def transaction(self, /) -> bool: ...
    def userName(self, /) -> str: ...


class QSqlDriver(PySide6.QtCore.QObject):

    notification             : typing.ClassVar[Signal] = ... # notification(QString,QSqlDriver::NotificationSource,QVariant)

    class DbmsType(enum.Enum):

        UnknownDbms               = 0x0
        MSSqlServer               = 0x1
        MySqlServer               = 0x2
        PostgreSQL                = 0x3
        Oracle                    = 0x4
        Sybase                    = 0x5
        SQLite                    = 0x6
        Interbase                 = 0x7
        DB2                       = 0x8
        MimerSQL                  = 0x9

    class DriverFeature(enum.Enum):

        Transactions              = 0x0
        QuerySize                 = 0x1
        BLOB                      = 0x2
        Unicode                   = 0x3
        PreparedQueries           = 0x4
        NamedPlaceholders         = 0x5
        PositionalPlaceholders    = 0x6
        LastInsertId              = 0x7
        BatchOperations           = 0x8
        SimpleLocking             = 0x9
        LowPrecisionNumbers       = 0xa
        EventNotifications        = 0xb
        FinishQuery               = 0xc
        MultipleResultSets        = 0xd
        CancelQuery               = 0xe

    class IdentifierType(enum.Enum):

        FieldName                 = 0x0
        TableName                 = 0x1

    class NotificationSource(enum.Enum):

        UnknownSource             = 0x0
        SelfSource                = 0x1
        OtherSource               = 0x2

    class StatementType(enum.Enum):

        WhereStatement            = 0x0
        SelectStatement           = 0x1
        UpdateStatement           = 0x2
        InsertStatement           = 0x3
        DeleteStatement           = 0x4


    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, numericalPrecisionPolicy: PySide6.QtSql.QSql.NumericalPrecisionPolicy | None = ...) -> None: ...

    def beginTransaction(self, /) -> bool: ...
    def cancelQuery(self, /) -> bool: ...
    def close(self, /) -> None: ...
    def commitTransaction(self, /) -> bool: ...
    def connectionName(self, /) -> str: ...
    def createResult(self, /) -> PySide6.QtSql.QSqlResult: ...
    def dbmsType(self, /) -> PySide6.QtSql.QSqlDriver.DbmsType: ...
    def escapeIdentifier(self, identifier: str, type: PySide6.QtSql.QSqlDriver.IdentifierType, /) -> str: ...
    def formatValue(self, field: PySide6.QtSql.QSqlField, /, trimStrings: bool = ...) -> str: ...
    def hasFeature(self, f: PySide6.QtSql.QSqlDriver.DriverFeature, /) -> bool: ...
    def isIdentifierEscaped(self, identifier: str, type: PySide6.QtSql.QSqlDriver.IdentifierType, /) -> bool: ...
    def isOpen(self, /) -> bool: ...
    def isOpenError(self, /) -> bool: ...
    def lastError(self, /) -> PySide6.QtSql.QSqlError: ...
    def maximumIdentifierLength(self, type: PySide6.QtSql.QSqlDriver.IdentifierType, /) -> int: ...
    def numericalPrecisionPolicy(self, /) -> PySide6.QtSql.QSql.NumericalPrecisionPolicy: ...
    def open(self, db: str, /, user: str = ..., password: str = ..., host: str = ..., port: int = ..., connOpts: str = ...) -> bool: ...
    def primaryIndex(self, tableName: str, /) -> PySide6.QtSql.QSqlIndex: ...
    def record(self, tableName: str, /) -> PySide6.QtSql.QSqlRecord: ...
    def rollbackTransaction(self, /) -> bool: ...
    def setLastError(self, e: PySide6.QtSql.QSqlError, /) -> None: ...
    def setNumericalPrecisionPolicy(self, precisionPolicy: PySide6.QtSql.QSql.NumericalPrecisionPolicy, /) -> None: ...
    def setOpen(self, o: bool, /) -> None: ...
    def setOpenError(self, e: bool, /) -> None: ...
    def sqlStatement(self, type: PySide6.QtSql.QSqlDriver.StatementType, tableName: str, rec: PySide6.QtSql.QSqlRecord, preparedStatement: bool, /) -> str: ...
    def stripDelimiters(self, identifier: str, type: PySide6.QtSql.QSqlDriver.IdentifierType, /) -> str: ...
    def subscribeToNotification(self, name: str, /) -> bool: ...
    def subscribedToNotifications(self, /) -> typing.List[str]: ...
    def tables(self, tableType: PySide6.QtSql.QSql.TableType, /) -> typing.List[str]: ...
    def unsubscribeFromNotification(self, name: str, /) -> bool: ...


class QSqlDriverCreatorBase(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def createObject(self, /) -> PySide6.QtSql.QSqlDriver: ...


class QSqlError(Shiboken.Object):

    class ErrorType(enum.Enum):

        NoError                   = 0x0
        ConnectionError           = 0x1
        StatementError            = 0x2
        TransactionError          = 0x3
        UnknownError              = 0x4


    @typing.overload
    def __init__(self, other: PySide6.QtSql.QSqlError, /) -> None: ...
    @typing.overload
    def __init__(self, /, driverText: str = ..., databaseText: str = ..., type: PySide6.QtSql.QSqlError.ErrorType = ..., nativeErrorCode: str = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, other: PySide6.QtSql.QSqlError, /) -> bool: ...
    def __ne__(self, other: PySide6.QtSql.QSqlError, /) -> bool: ...
    def __repr__(self, /) -> str: ...
    def databaseText(self, /) -> str: ...
    def driverText(self, /) -> str: ...
    def isValid(self, /) -> bool: ...
    def nativeErrorCode(self, /) -> str: ...
    def swap(self, other: PySide6.QtSql.QSqlError, /) -> None: ...
    def text(self, /) -> str: ...
    def type(self, /) -> PySide6.QtSql.QSqlError.ErrorType: ...


class QSqlField(Shiboken.Object):

    class RequiredStatus(enum.Enum):

        Unknown                   = -1
        Optional                  = 0x0
        Required                  = 0x1


    @typing.overload
    def __init__(self, other: PySide6.QtSql.QSqlField, /, *, value: typing.Any | None = ..., defaultValue: typing.Any | None = ..., name: str | None = ..., tableName: str | None = ..., metaType: PySide6.QtCore.QMetaType | None = ..., requiredStatus: PySide6.QtSql.QSqlField.RequiredStatus | None = ..., readOnly: bool | None = ..., generated: bool | None = ..., autoValue: bool | None = ..., length: int | None = ..., precision: int | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, fieldName: str = ..., type: PySide6.QtCore.QMetaType | PySide6.QtCore.QMetaType.Type = ..., tableName: str = ..., *, value: typing.Any | None = ..., defaultValue: typing.Any | None = ..., name: str | None = ..., metaType: PySide6.QtCore.QMetaType | None = ..., requiredStatus: PySide6.QtSql.QSqlField.RequiredStatus | None = ..., readOnly: bool | None = ..., generated: bool | None = ..., autoValue: bool | None = ..., length: int | None = ..., precision: int | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, other: PySide6.QtSql.QSqlField, /) -> bool: ...
    def __ne__(self, other: PySide6.QtSql.QSqlField, /) -> bool: ...
    def __repr__(self, /) -> str: ...
    def clear(self, /) -> None: ...
    def defaultValue(self, /) -> typing.Any: ...
    def isAutoValue(self, /) -> bool: ...
    def isGenerated(self, /) -> bool: ...
    def isNull(self, /) -> bool: ...
    def isReadOnly(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def length(self, /) -> int: ...
    def metaType(self, /) -> PySide6.QtCore.QMetaType: ...
    def name(self, /) -> str: ...
    def precision(self, /) -> int: ...
    def requiredStatus(self, /) -> PySide6.QtSql.QSqlField.RequiredStatus: ...
    def setAutoValue(self, autoVal: bool, /) -> None: ...
    def setDefaultValue(self, value: typing.Any, /) -> None: ...
    def setGenerated(self, gen: bool, /) -> None: ...
    def setLength(self, fieldLength: int, /) -> None: ...
    def setMetaType(self, type: PySide6.QtCore.QMetaType | PySide6.QtCore.QMetaType.Type, /) -> None: ...
    def setName(self, name: str, /) -> None: ...
    def setPrecision(self, precision: int, /) -> None: ...
    def setReadOnly(self, readOnly: bool, /) -> None: ...
    def setRequired(self, required: bool, /) -> None: ...
    def setRequiredStatus(self, status: PySide6.QtSql.QSqlField.RequiredStatus, /) -> None: ...
    def setSqlType(self, type: int, /) -> None: ...
    def setTableName(self, tableName: str, /) -> None: ...
    def setValue(self, value: typing.Any, /) -> None: ...
    def swap(self, other: PySide6.QtSql.QSqlField, /) -> None: ...
    def tableName(self, /) -> str: ...
    def typeID(self, /) -> int: ...
    def value(self, /) -> typing.Any: ...


class QSqlIndex(PySide6.QtSql.QSqlRecord):

    @typing.overload
    def __init__(self, other: PySide6.QtSql.QSqlIndex, /, *, name: str | None = ..., cursorName: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, cursorName: str = ..., name: str = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    @typing.overload
    def append(self, field: PySide6.QtSql.QSqlField, /) -> None: ...
    @typing.overload
    def append(self, field: PySide6.QtSql.QSqlField, desc: bool, /) -> None: ...
    def cursorName(self, /) -> str: ...
    def isDescending(self, i: int, /) -> bool: ...
    def name(self, /) -> str: ...
    def setCursorName(self, cursorName: str, /) -> None: ...
    def setDescending(self, i: int, desc: bool, /) -> None: ...
    def setName(self, name: str, /) -> None: ...
    def swap(self, other: PySide6.QtSql.QSqlIndex, /) -> None: ...


class QSqlQuery(Shiboken.Object):

    class BatchExecutionMode(enum.Enum):

        ValuesAsRows              = 0x0
        ValuesAsColumns           = 0x1


    @typing.overload
    def __init__(self, db: PySide6.QtSql.QSqlDatabase, /, *, forwardOnly: bool | None = ..., positionalBindingEnabled: bool | None = ..., numericalPrecisionPolicy: PySide6.QtSql.QSql.NumericalPrecisionPolicy | None = ...) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtSql.QSqlQuery, /, *, forwardOnly: bool | None = ..., positionalBindingEnabled: bool | None = ..., numericalPrecisionPolicy: PySide6.QtSql.QSql.NumericalPrecisionPolicy | None = ...) -> None: ...
    @typing.overload
    def __init__(self, r: PySide6.QtSql.QSqlResult, /, *, forwardOnly: bool | None = ..., positionalBindingEnabled: bool | None = ..., numericalPrecisionPolicy: PySide6.QtSql.QSql.NumericalPrecisionPolicy | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, query: str = ..., db: PySide6.QtSql.QSqlDatabase = ..., *, forwardOnly: bool | None = ..., positionalBindingEnabled: bool | None = ..., numericalPrecisionPolicy: PySide6.QtSql.QSql.NumericalPrecisionPolicy | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def addBindValue(self, val: typing.Any, /, type: PySide6.QtSql.QSql.ParamTypeFlag = ...) -> None: ...
    def at(self, /) -> int: ...
    @typing.overload
    def bindValue(self, placeholder: str, val: typing.Any, /, type: PySide6.QtSql.QSql.ParamTypeFlag = ...) -> None: ...
    @typing.overload
    def bindValue(self, pos: int, val: typing.Any, /, type: PySide6.QtSql.QSql.ParamTypeFlag = ...) -> None: ...
    @typing.overload
    def boundValue(self, placeholder: str, /) -> typing.Any: ...
    @typing.overload
    def boundValue(self, pos: int, /) -> typing.Any: ...
    def boundValueName(self, pos: int, /) -> str: ...
    def boundValueNames(self, /) -> typing.List[str]: ...
    def boundValues(self, /) -> typing.List[typing.Any]: ...
    def clear(self, /) -> None: ...
    def driver(self, /) -> PySide6.QtSql.QSqlDriver: ...
    @typing.overload
    def exec(self, /) -> bool: ...
    @typing.overload
    def exec(self, query: str, /) -> bool: ...
    def execBatch(self, /, mode: PySide6.QtSql.QSqlQuery.BatchExecutionMode = ...) -> bool: ...
    @typing.overload
    def exec_(self, /) -> bool: ...
    @typing.overload
    def exec_(self, arg__1: str, /) -> bool: ...
    def executedQuery(self, /) -> str: ...
    def finish(self, /) -> None: ...
    def first(self, /) -> bool: ...
    def isActive(self, /) -> bool: ...
    def isForwardOnly(self, /) -> bool: ...
    @typing.overload
    def isNull(self, name: str, /) -> bool: ...
    @typing.overload
    def isNull(self, field: int, /) -> bool: ...
    def isPositionalBindingEnabled(self, /) -> bool: ...
    def isSelect(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def last(self, /) -> bool: ...
    def lastError(self, /) -> PySide6.QtSql.QSqlError: ...
    def lastInsertId(self, /) -> typing.Any: ...
    def lastQuery(self, /) -> str: ...
    def next(self, /) -> bool: ...
    def nextResult(self, /) -> bool: ...
    def numRowsAffected(self, /) -> int: ...
    def numericalPrecisionPolicy(self, /) -> PySide6.QtSql.QSql.NumericalPrecisionPolicy: ...
    def prepare(self, query: str, /) -> bool: ...
    def previous(self, /) -> bool: ...
    def record(self, /) -> PySide6.QtSql.QSqlRecord: ...
    def result(self, /) -> PySide6.QtSql.QSqlResult: ...
    def seek(self, i: int, /, relative: bool = ...) -> bool: ...
    def setForwardOnly(self, forward: bool, /) -> None: ...
    def setNumericalPrecisionPolicy(self, precisionPolicy: PySide6.QtSql.QSql.NumericalPrecisionPolicy, /) -> None: ...
    def setPositionalBindingEnabled(self, enable: bool, /) -> None: ...
    def size(self, /) -> int: ...
    def swap(self, other: PySide6.QtSql.QSqlQuery, /) -> None: ...
    @typing.overload
    def value(self, name: str, /) -> typing.Any: ...
    @typing.overload
    def value(self, i: int, /) -> typing.Any: ...


class QSqlQueryModel(PySide6.QtCore.QAbstractTableModel):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def beginInsertColumns(self, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, first: int, last: int, /) -> None: ...
    def beginInsertRows(self, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, first: int, last: int, /) -> None: ...
    def beginRemoveColumns(self, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, first: int, last: int, /) -> None: ...
    def beginRemoveRows(self, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, first: int, last: int, /) -> None: ...
    def beginResetModel(self, /) -> None: ...
    def canFetchMore(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> bool: ...
    def clear(self, /) -> None: ...
    def columnCount(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> int: ...
    def data(self, item: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /, role: int = ...) -> typing.Any: ...
    def endInsertColumns(self, /) -> None: ...
    def endInsertRows(self, /) -> None: ...
    def endRemoveColumns(self, /) -> None: ...
    def endRemoveRows(self, /) -> None: ...
    def endResetModel(self, /) -> None: ...
    def fetchMore(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> None: ...
    def headerData(self, section: int, orientation: PySide6.QtCore.Qt.Orientation, /, role: int = ...) -> typing.Any: ...
    def indexInQuery(self, item: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> PySide6.QtCore.QModelIndex: ...
    def insertColumns(self, column: int, count: int, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> bool: ...
    def lastError(self, /) -> PySide6.QtSql.QSqlError: ...
    def query(self, /) -> PySide6.QtSql.QSqlQuery: ...
    def queryChange(self, /) -> None: ...
    @typing.overload
    def record(self, /) -> PySide6.QtSql.QSqlRecord: ...
    @typing.overload
    def record(self, row: int, /) -> PySide6.QtSql.QSqlRecord: ...
    def refresh(self, /) -> None: ...
    def removeColumns(self, column: int, count: int, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> bool: ...
    def roleNames(self, /) -> typing.Dict[int, PySide6.QtCore.QByteArray]: ...
    def rowCount(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> int: ...
    def setHeaderData(self, section: int, orientation: PySide6.QtCore.Qt.Orientation, value: typing.Any, /, role: int = ...) -> bool: ...
    def setLastError(self, error: PySide6.QtSql.QSqlError, /) -> None: ...
    @typing.overload
    def setQuery(self, query: PySide6.QtSql.QSqlQuery, /) -> None: ...
    @typing.overload
    def setQuery(self, query: str, /, db: PySide6.QtSql.QSqlDatabase = ...) -> None: ...


class QSqlRecord(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtSql.QSqlRecord, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, other: PySide6.QtSql.QSqlRecord, /) -> bool: ...
    def __ne__(self, other: PySide6.QtSql.QSqlRecord, /) -> bool: ...
    def __repr__(self, /) -> str: ...
    def append(self, field: PySide6.QtSql.QSqlField, /) -> None: ...
    def clear(self, /) -> None: ...
    def clearValues(self, /) -> None: ...
    def contains(self, name: str, /) -> bool: ...
    def count(self, /) -> int: ...
    @typing.overload
    def field(self, name: str, /) -> PySide6.QtSql.QSqlField: ...
    @typing.overload
    def field(self, i: int, /) -> PySide6.QtSql.QSqlField: ...
    def fieldName(self, i: int, /) -> str: ...
    def indexOf(self, name: str, /) -> int: ...
    def insert(self, pos: int, field: PySide6.QtSql.QSqlField, /) -> None: ...
    def isEmpty(self, /) -> bool: ...
    @typing.overload
    def isGenerated(self, name: str, /) -> bool: ...
    @typing.overload
    def isGenerated(self, i: int, /) -> bool: ...
    @typing.overload
    def isNull(self, name: str, /) -> bool: ...
    @typing.overload
    def isNull(self, i: int, /) -> bool: ...
    def keyValues(self, keyFields: PySide6.QtSql.QSqlRecord, /) -> PySide6.QtSql.QSqlRecord: ...
    def remove(self, pos: int, /) -> None: ...
    def replace(self, pos: int, field: PySide6.QtSql.QSqlField, /) -> None: ...
    @typing.overload
    def setGenerated(self, name: str, generated: bool, /) -> None: ...
    @typing.overload
    def setGenerated(self, i: int, generated: bool, /) -> None: ...
    @typing.overload
    def setNull(self, name: str, /) -> None: ...
    @typing.overload
    def setNull(self, i: int, /) -> None: ...
    @typing.overload
    def setValue(self, name: str, val: typing.Any, /) -> None: ...
    @typing.overload
    def setValue(self, i: int, val: typing.Any, /) -> None: ...
    def swap(self, other: PySide6.QtSql.QSqlRecord, /) -> None: ...
    @typing.overload
    def value(self, name: str, /) -> typing.Any: ...
    @typing.overload
    def value(self, i: int, /) -> typing.Any: ...


class QSqlRelation(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QSqlRelation: PySide6.QtSql.QSqlRelation, /) -> None: ...
    @typing.overload
    def __init__(self, aTableName: str, indexCol: str, displayCol: str, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def displayColumn(self, /) -> str: ...
    def indexColumn(self, /) -> str: ...
    def isValid(self, /) -> bool: ...
    def swap(self, other: PySide6.QtSql.QSqlRelation, /) -> None: ...
    def tableName(self, /) -> str: ...


class QSqlRelationalDelegate(PySide6.QtWidgets.QStyledItemDelegate):

    def __init__(self, /, aParent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def createEditor(self, aParent: PySide6.QtWidgets.QWidget, option: PySide6.QtWidgets.QStyleOptionViewItem, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> PySide6.QtWidgets.QWidget: ...
    def setEditorData(self, editor: PySide6.QtWidgets.QWidget, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> None: ...
    def setModelData(self, editor: PySide6.QtWidgets.QWidget, model: PySide6.QtCore.QAbstractItemModel, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> None: ...


class QSqlRelationalTableModel(PySide6.QtSql.QSqlTableModel):

    class JoinMode(enum.Enum):

        InnerJoin                 = 0x0
        LeftJoin                  = 0x1


    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., db: PySide6.QtSql.QSqlDatabase = ...) -> None: ...

    def clear(self, /) -> None: ...
    def data(self, item: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /, role: int = ...) -> typing.Any: ...
    def insertRowIntoTable(self, values: PySide6.QtSql.QSqlRecord, /) -> bool: ...
    def orderByClause(self, /) -> str: ...
    def relation(self, column: int, /) -> PySide6.QtSql.QSqlRelation: ...
    def relationModel(self, column: int, /) -> PySide6.QtSql.QSqlTableModel: ...
    def removeColumns(self, column: int, count: int, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> bool: ...
    def revertRow(self, row: int, /) -> None: ...
    def select(self, /) -> bool: ...
    def selectStatement(self, /) -> str: ...
    def setData(self, item: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, value: typing.Any, /, role: int = ...) -> bool: ...
    def setJoinMode(self, joinMode: PySide6.QtSql.QSqlRelationalTableModel.JoinMode, /) -> None: ...
    def setRelation(self, column: int, relation: PySide6.QtSql.QSqlRelation, /) -> None: ...
    def setTable(self, tableName: str, /) -> None: ...
    def updateRowInTable(self, row: int, values: PySide6.QtSql.QSqlRecord, /) -> bool: ...


class QSqlResult(Shiboken.Object):

    class BindingSyntax(enum.Enum):

        PositionalBinding         = 0x0
        NamedBinding              = 0x1

    class VirtualHookOperation(enum.Enum): ...  # type: ignore[misc]


    def __init__(self, db: PySide6.QtSql.QSqlDriver, /) -> None: ...

    def addBindValue(self, val: typing.Any, type: PySide6.QtSql.QSql.ParamTypeFlag, /) -> None: ...
    def at(self, /) -> int: ...
    @typing.overload
    def bindValue(self, placeholder: str, val: typing.Any, type: PySide6.QtSql.QSql.ParamTypeFlag, /) -> None: ...
    @typing.overload
    def bindValue(self, pos: int, val: typing.Any, type: PySide6.QtSql.QSql.ParamTypeFlag, /) -> None: ...
    @typing.overload
    def bindValueType(self, placeholder: str, /) -> PySide6.QtSql.QSql.ParamTypeFlag: ...
    @typing.overload
    def bindValueType(self, pos: int, /) -> PySide6.QtSql.QSql.ParamTypeFlag: ...
    def bindingSyntax(self, /) -> PySide6.QtSql.QSqlResult.BindingSyntax: ...
    @typing.overload
    def boundValue(self, placeholder: str, /) -> typing.Any: ...
    @typing.overload
    def boundValue(self, pos: int, /) -> typing.Any: ...
    def boundValueCount(self, /) -> int: ...
    def boundValueName(self, pos: int, /) -> str: ...
    def boundValueNames(self, /) -> typing.List[str]: ...
    def boundValues(self, /) -> typing.List[typing.Any]: ...
    def clear(self, /) -> None: ...
    def data(self, i: int, /) -> typing.Any: ...
    def detachFromResultSet(self, /) -> None: ...
    def driver(self, /) -> PySide6.QtSql.QSqlDriver: ...
    def exec(self, /) -> bool: ...
    def execBatch(self, /, arrayBind: bool = ...) -> bool: ...
    def exec_(self, /) -> bool: ...
    def executedQuery(self, /) -> str: ...
    def fetch(self, i: int, /) -> bool: ...
    def fetchFirst(self, /) -> bool: ...
    def fetchLast(self, /) -> bool: ...
    def fetchNext(self, /) -> bool: ...
    def fetchPrevious(self, /) -> bool: ...
    def handle(self, /) -> typing.Any: ...
    def hasOutValues(self, /) -> bool: ...
    def isActive(self, /) -> bool: ...
    def isForwardOnly(self, /) -> bool: ...
    def isNull(self, i: int, /) -> bool: ...
    def isPositionalBindingEnabled(self, /) -> bool: ...
    def isSelect(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def lastError(self, /) -> PySide6.QtSql.QSqlError: ...
    def lastInsertId(self, /) -> typing.Any: ...
    def lastQuery(self, /) -> str: ...
    def nextResult(self, /) -> bool: ...
    def numRowsAffected(self, /) -> int: ...
    def numericalPrecisionPolicy(self, /) -> PySide6.QtSql.QSql.NumericalPrecisionPolicy: ...
    def prepare(self, query: str, /) -> bool: ...
    def record(self, /) -> PySide6.QtSql.QSqlRecord: ...
    def reset(self, sqlquery: str, /) -> bool: ...
    def resetBindCount(self, /) -> None: ...
    def savePrepare(self, sqlquery: str, /) -> bool: ...
    def setActive(self, a: bool, /) -> None: ...
    def setAt(self, at: int, /) -> None: ...
    def setForwardOnly(self, forward: bool, /) -> None: ...
    def setLastError(self, e: PySide6.QtSql.QSqlError, /) -> None: ...
    def setNumericalPrecisionPolicy(self, policy: PySide6.QtSql.QSql.NumericalPrecisionPolicy, /) -> None: ...
    def setPositionalBindingEnabled(self, enable: bool, /) -> None: ...
    def setQuery(self, query: str, /) -> None: ...
    def setSelect(self, s: bool, /) -> None: ...
    def size(self, /) -> int: ...


class QSqlTableModel(PySide6.QtSql.QSqlQueryModel):

    beforeDelete             : typing.ClassVar[Signal] = ... # beforeDelete(int)
    beforeInsert             : typing.ClassVar[Signal] = ... # beforeInsert(QSqlRecord&)
    beforeUpdate             : typing.ClassVar[Signal] = ... # beforeUpdate(int,QSqlRecord&)
    primeInsert              : typing.ClassVar[Signal] = ... # primeInsert(int,QSqlRecord&)

    class EditStrategy(enum.Enum):

        OnFieldChange             = 0x0
        OnRowChange               = 0x1
        OnManualSubmit            = 0x2


    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., db: PySide6.QtSql.QSqlDatabase = ...) -> None: ...

    def clear(self, /) -> None: ...
    def clearItemData(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> bool: ...
    def data(self, idx: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /, role: int = ...) -> typing.Any: ...
    def database(self, /) -> PySide6.QtSql.QSqlDatabase: ...
    def deleteRowFromTable(self, row: int, /) -> bool: ...
    def editStrategy(self, /) -> PySide6.QtSql.QSqlTableModel.EditStrategy: ...
    def fieldIndex(self, fieldName: str, /) -> int: ...
    def filter(self, /) -> str: ...
    def flags(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> PySide6.QtCore.Qt.ItemFlag: ...
    def headerData(self, section: int, orientation: PySide6.QtCore.Qt.Orientation, /, role: int = ...) -> typing.Any: ...
    def indexInQuery(self, item: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> PySide6.QtCore.QModelIndex: ...
    def insertRecord(self, row: int, record: PySide6.QtSql.QSqlRecord, /) -> bool: ...
    def insertRowIntoTable(self, values: PySide6.QtSql.QSqlRecord, /) -> bool: ...
    def insertRows(self, row: int, count: int, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> bool: ...
    @typing.overload
    def isDirty(self, /) -> bool: ...
    @typing.overload
    def isDirty(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> bool: ...
    def orderByClause(self, /) -> str: ...
    def primaryKey(self, /) -> PySide6.QtSql.QSqlIndex: ...
    def primaryValues(self, row: int, /) -> PySide6.QtSql.QSqlRecord: ...
    @typing.overload
    def record(self, /) -> PySide6.QtSql.QSqlRecord: ...
    @typing.overload
    def record(self, row: int, /) -> PySide6.QtSql.QSqlRecord: ...
    def removeColumns(self, column: int, count: int, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> bool: ...
    def removeRows(self, row: int, count: int, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> bool: ...
    def revert(self, /) -> None: ...
    def revertAll(self, /) -> None: ...
    def revertRow(self, row: int, /) -> None: ...
    def rowCount(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> int: ...
    def select(self, /) -> bool: ...
    def selectRow(self, row: int, /) -> bool: ...
    def selectStatement(self, /) -> str: ...
    def setData(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, value: typing.Any, /, role: int = ...) -> bool: ...
    def setEditStrategy(self, strategy: PySide6.QtSql.QSqlTableModel.EditStrategy, /) -> None: ...
    def setFilter(self, filter: str, /) -> None: ...
    def setPrimaryKey(self, key: PySide6.QtSql.QSqlIndex, /) -> None: ...
    def setRecord(self, row: int, record: PySide6.QtSql.QSqlRecord, /) -> bool: ...
    def setSort(self, column: int, order: PySide6.QtCore.Qt.SortOrder, /) -> None: ...
    def setTable(self, tableName: str, /) -> None: ...
    def sort(self, column: int, order: PySide6.QtCore.Qt.SortOrder, /) -> None: ...
    def submit(self, /) -> bool: ...
    def submitAll(self, /) -> bool: ...
    def tableName(self, /) -> str: ...
    def updateRowInTable(self, row: int, values: PySide6.QtSql.QSqlRecord, /) -> bool: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtUiTools, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtUiTools`

import PySide6.QtUiTools
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtWidgets

import os
import typing
import collections.abc


class QIntList: ...


class QUiLoader(PySide6.QtCore.QObject):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def addPluginPath(self, path: str, /) -> None: ...
    def availableLayouts(self, /) -> typing.List[str]: ...
    def availableWidgets(self, /) -> typing.List[str]: ...
    def clearPluginPaths(self, /) -> None: ...
    def createAction(self, /, parent: PySide6.QtCore.QObject | None = ..., name: str = ...) -> PySide6.QtGui.QAction: ...
    def createActionGroup(self, /, parent: PySide6.QtCore.QObject | None = ..., name: str = ...) -> PySide6.QtGui.QActionGroup: ...
    def createLayout(self, className: str, /, parent: PySide6.QtCore.QObject | None = ..., name: str = ...) -> PySide6.QtWidgets.QLayout: ...
    def createWidget(self, className: str, /, parent: PySide6.QtWidgets.QWidget | None = ..., name: str = ...) -> PySide6.QtWidgets.QWidget: ...
    def errorString(self, /) -> str: ...
    def isLanguageChangeEnabled(self, /) -> bool: ...
    def isTranslationEnabled(self, /) -> bool: ...
    @typing.overload
    def load(self, device: PySide6.QtCore.QIODevice, /, parentWidget: PySide6.QtWidgets.QWidget | None = ...) -> PySide6.QtWidgets.QWidget: ...
    @typing.overload
    def load(self, arg__1: str | bytes | os.PathLike[str], /, parentWidget: PySide6.QtWidgets.QWidget | None = ...) -> PySide6.QtWidgets.QWidget: ...
    def pluginPaths(self, /) -> typing.List[str]: ...
    def registerCustomWidget(self, customWidgetType: object, /) -> None: ...
    def setLanguageChangeEnabled(self, enabled: bool, /) -> None: ...
    def setTranslationEnabled(self, enabled: bool, /) -> None: ...
    def setWorkingDirectory(self, dir: PySide6.QtCore.QDir, /) -> None: ...
    def workingDirectory(self, /) -> PySide6.QtCore.QDir: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...
def loadUiType(uifile: str, /) -> object: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtQuickTest, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtQuickTest`

import PySide6.QtQuickTest

import collections.abc


class QIntList: ...


def QUICK_TEST_MAIN(name: str, /, argv: collections.abc.Sequence[str] = ..., dir: str = ...) -> int: ...
def QUICK_TEST_MAIN_WITH_SETUP(name: str, setup: type, /, argv: collections.abc.Sequence[str] = ..., dir: str = ...) -> int: ...
def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtPdf, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtPdf`

import PySide6.QtPdf
import PySide6.QtCore
import PySide6.QtGui

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class QPdfBookmarkModel(PySide6.QtCore.QAbstractItemModel):

    documentChanged          : typing.ClassVar[Signal] = ... # documentChanged(QPdfDocument*)

    class Role(enum.IntEnum):

        Title                     = 0x100
        Level                     = 0x101
        Page                      = 0x102
        Location                  = 0x103
        Zoom                      = 0x104
        NRoles                    = 0x105


    @typing.overload
    def __init__(self, parent: PySide6.QtCore.QObject, /, *, document: PySide6.QtPdf.QPdfDocument | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, document: PySide6.QtPdf.QPdfDocument | None = ...) -> None: ...

    def columnCount(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> int: ...
    def data(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, role: int, /) -> typing.Any: ...
    def document(self, /) -> PySide6.QtPdf.QPdfDocument: ...
    def index(self, row: int, column: int, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> PySide6.QtCore.QModelIndex: ...
    @typing.overload
    def parent(self, /) -> PySide6.QtCore.QObject: ...
    @typing.overload
    def parent(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> PySide6.QtCore.QModelIndex: ...
    def roleNames(self, /) -> typing.Dict[int, PySide6.QtCore.QByteArray]: ...
    def rowCount(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> int: ...
    def setDocument(self, document: PySide6.QtPdf.QPdfDocument, /) -> None: ...


class QPdfDocument(PySide6.QtCore.QObject):

    pageCountChanged         : typing.ClassVar[Signal] = ... # pageCountChanged(int)
    pageModelChanged         : typing.ClassVar[Signal] = ... # pageModelChanged()
    passwordChanged          : typing.ClassVar[Signal] = ... # passwordChanged()
    passwordRequired         : typing.ClassVar[Signal] = ... # passwordRequired()
    statusChanged            : typing.ClassVar[Signal] = ... # statusChanged(QPdfDocument::Status)

    class Error(enum.Enum):

        None_                     = 0x0
        Unknown                   = 0x1
        DataNotYetAvailable       = 0x2
        FileNotFound              = 0x3
        InvalidFileFormat         = 0x4
        IncorrectPassword         = 0x5
        UnsupportedSecurityScheme = 0x6

    class MetaDataField(enum.Enum):

        Title                     = 0x0
        Subject                   = 0x1
        Author                    = 0x2
        Keywords                  = 0x3
        Producer                  = 0x4
        Creator                   = 0x5
        CreationDate              = 0x6
        ModificationDate          = 0x7

    class PageModelRole(enum.Enum):

        Label                     = 0x100
        PointSize                 = 0x101
        NRoles                    = 0x102

    class Status(enum.Enum):

        Null                      = 0x0
        Loading                   = 0x1
        Ready                     = 0x2
        Unloading                 = 0x3
        Error                     = 0x4


    @typing.overload
    def __init__(self, parent: PySide6.QtCore.QObject, /, *, pageCount: int | None = ..., password: str | None = ..., status: PySide6.QtPdf.QPdfDocument.Status | None = ..., pageModel: PySide6.QtCore.QAbstractListModel | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, pageCount: int | None = ..., password: str | None = ..., status: PySide6.QtPdf.QPdfDocument.Status | None = ..., pageModel: PySide6.QtCore.QAbstractListModel | None = ...) -> None: ...

    def close(self, /) -> None: ...
    def error(self, /) -> PySide6.QtPdf.QPdfDocument.Error: ...
    def getAllText(self, page: int, /) -> PySide6.QtPdf.QPdfSelection: ...
    def getSelection(self, page: int, start: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, end: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> PySide6.QtPdf.QPdfSelection: ...
    def getSelectionAtIndex(self, page: int, startIndex: int, maxLength: int, /) -> PySide6.QtPdf.QPdfSelection: ...
    @typing.overload
    def load(self, device: PySide6.QtCore.QIODevice, /) -> None: ...
    @typing.overload
    def load(self, fileName: str, /) -> PySide6.QtPdf.QPdfDocument.Error: ...
    def metaData(self, field: PySide6.QtPdf.QPdfDocument.MetaDataField, /) -> typing.Any: ...
    def pageCount(self, /) -> int: ...
    def pageIndexForLabel(self, label: str, /) -> int: ...
    def pageLabel(self, page: int, /) -> str: ...
    def pageModel(self, /) -> PySide6.QtCore.QAbstractListModel: ...
    def pagePointSize(self, page: int, /) -> PySide6.QtCore.QSizeF: ...
    def password(self, /) -> str: ...
    def render(self, page: int, imageSize: PySide6.QtCore.QSize, /, options: PySide6.QtPdf.QPdfDocumentRenderOptions = ...) -> PySide6.QtGui.QImage: ...
    def setPassword(self, password: str, /) -> None: ...
    def status(self, /) -> PySide6.QtPdf.QPdfDocument.Status: ...


class QPdfDocumentRenderOptions(Shiboken.Object):

    class RenderFlag(enum.Flag):

        None_                     = 0x0
        Annotations               = 0x1
        OptimizedForLcd           = 0x2
        Grayscale                 = 0x4
        ForceHalftone             = 0x8
        TextAliased               = 0x10
        ImageAliased              = 0x20
        PathAliased               = 0x40

    class Rotation(enum.Enum):

        None_                     = 0x0
        Clockwise90               = 0x1
        Clockwise180              = 0x2
        Clockwise270              = 0x3


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QPdfDocumentRenderOptions: PySide6.QtPdf.QPdfDocumentRenderOptions, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtPdf.QPdfDocumentRenderOptions, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtPdf.QPdfDocumentRenderOptions, /) -> bool: ...
    def renderFlags(self, /) -> PySide6.QtPdf.QPdfDocumentRenderOptions.RenderFlag: ...
    def rotation(self, /) -> PySide6.QtPdf.QPdfDocumentRenderOptions.Rotation: ...
    def scaledClipRect(self, /) -> PySide6.QtCore.QRect: ...
    def scaledSize(self, /) -> PySide6.QtCore.QSize: ...
    def setRenderFlags(self, r: PySide6.QtPdf.QPdfDocumentRenderOptions.RenderFlag, /) -> None: ...
    def setRotation(self, r: PySide6.QtPdf.QPdfDocumentRenderOptions.Rotation, /) -> None: ...
    def setScaledClipRect(self, r: PySide6.QtCore.QRect, /) -> None: ...
    def setScaledSize(self, s: PySide6.QtCore.QSize, /) -> None: ...


class QPdfLink(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtPdf.QPdfLink, /, *, valid: bool | None = ..., page: int | None = ..., location: PySide6.QtCore.QPointF | None = ..., zoom: float | None = ..., url: PySide6.QtCore.QUrl | None = ..., contextBefore: str | None = ..., contextAfter: str | None = ..., rectangles: collections.abc.Sequence[PySide6.QtCore.QRectF] | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, valid: bool | None = ..., page: int | None = ..., location: PySide6.QtCore.QPointF | None = ..., zoom: float | None = ..., url: PySide6.QtCore.QUrl | None = ..., contextBefore: str | None = ..., contextAfter: str | None = ..., rectangles: collections.abc.Sequence[PySide6.QtCore.QRectF] | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __repr__(self, /) -> str: ...
    def contextAfter(self, /) -> str: ...
    def contextBefore(self, /) -> str: ...
    def copyToClipboard(self, /, mode: PySide6.QtGui.QClipboard.Mode = ...) -> None: ...
    def isValid(self, /) -> bool: ...
    def location(self, /) -> PySide6.QtCore.QPointF: ...
    def page(self, /) -> int: ...
    def rectangles(self, /) -> typing.List[PySide6.QtCore.QRectF]: ...
    def swap(self, other: PySide6.QtPdf.QPdfLink, /) -> None: ...
    def toString(self, /) -> str: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...
    def zoom(self, /) -> float: ...


class QPdfLinkModel(PySide6.QtCore.QAbstractListModel):

    documentChanged          : typing.ClassVar[Signal] = ... # documentChanged()
    pageChanged              : typing.ClassVar[Signal] = ... # pageChanged(int)

    class Role(enum.Enum):

        Link                      = 0x100
        Rectangle                 = 0x101
        Url                       = 0x102
        Page                      = 0x103
        Location                  = 0x104
        Zoom                      = 0x105
        NRoles                    = 0x106


    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, document: PySide6.QtPdf.QPdfDocument | None = ..., page: int | None = ...) -> None: ...

    def data(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, role: int, /) -> typing.Any: ...
    def document(self, /) -> PySide6.QtPdf.QPdfDocument: ...
    def linkAt(self, point: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> PySide6.QtPdf.QPdfLink: ...
    def page(self, /) -> int: ...
    def roleNames(self, /) -> typing.Dict[int, PySide6.QtCore.QByteArray]: ...
    def rowCount(self, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> int: ...
    def setDocument(self, document: PySide6.QtPdf.QPdfDocument, /) -> None: ...
    def setPage(self, page: int, /) -> None: ...


class QPdfPageNavigator(PySide6.QtCore.QObject):

    backAvailableChanged     : typing.ClassVar[Signal] = ... # backAvailableChanged(bool)
    currentLocationChanged   : typing.ClassVar[Signal] = ... # currentLocationChanged(QPointF)
    currentPageChanged       : typing.ClassVar[Signal] = ... # currentPageChanged(int)
    currentZoomChanged       : typing.ClassVar[Signal] = ... # currentZoomChanged(double)
    forwardAvailableChanged  : typing.ClassVar[Signal] = ... # forwardAvailableChanged(bool)
    jumped                   : typing.ClassVar[Signal] = ... # jumped(QPdfLink)

    @typing.overload
    def __init__(self, parent: PySide6.QtCore.QObject, /, *, currentPage: int | None = ..., currentLocation: PySide6.QtCore.QPointF | None = ..., currentZoom: float | None = ..., backAvailable: bool | None = ..., forwardAvailable: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, currentPage: int | None = ..., currentLocation: PySide6.QtCore.QPointF | None = ..., currentZoom: float | None = ..., backAvailable: bool | None = ..., forwardAvailable: bool | None = ...) -> None: ...

    def back(self, /) -> None: ...
    def backAvailable(self, /) -> bool: ...
    def clear(self, /) -> None: ...
    def currentLink(self, /) -> PySide6.QtPdf.QPdfLink: ...
    def currentLocation(self, /) -> PySide6.QtCore.QPointF: ...
    def currentPage(self, /) -> int: ...
    def currentZoom(self, /) -> float: ...
    def forward(self, /) -> None: ...
    def forwardAvailable(self, /) -> bool: ...
    @typing.overload
    def jump(self, destination: PySide6.QtPdf.QPdfLink, /) -> None: ...
    @typing.overload
    def jump(self, page: int, location: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /, zoom: float | None = ...) -> None: ...
    def update(self, page: int, location: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, zoom: float, /) -> None: ...


class QPdfPageRenderer(PySide6.QtCore.QObject):

    documentChanged          : typing.ClassVar[Signal] = ... # documentChanged(QPdfDocument*)
    pageRendered             : typing.ClassVar[Signal] = ... # pageRendered(int,QSize,QImage,QPdfDocumentRenderOptions,qulonglong)
    renderModeChanged        : typing.ClassVar[Signal] = ... # renderModeChanged(QPdfPageRenderer::RenderMode)

    class RenderMode(enum.Enum):

        MultiThreaded             = 0x0
        SingleThreaded            = 0x1


    @typing.overload
    def __init__(self, parent: PySide6.QtCore.QObject, /, *, document: PySide6.QtPdf.QPdfDocument | None = ..., renderMode: PySide6.QtPdf.QPdfPageRenderer.RenderMode | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, document: PySide6.QtPdf.QPdfDocument | None = ..., renderMode: PySide6.QtPdf.QPdfPageRenderer.RenderMode | None = ...) -> None: ...

    def document(self, /) -> PySide6.QtPdf.QPdfDocument: ...
    def renderMode(self, /) -> PySide6.QtPdf.QPdfPageRenderer.RenderMode: ...
    def requestPage(self, pageNumber: int, imageSize: PySide6.QtCore.QSize, /, options: PySide6.QtPdf.QPdfDocumentRenderOptions = ...) -> int: ...
    def setDocument(self, document: PySide6.QtPdf.QPdfDocument, /) -> None: ...
    def setRenderMode(self, mode: PySide6.QtPdf.QPdfPageRenderer.RenderMode, /) -> None: ...


class QPdfSearchModel(PySide6.QtCore.QAbstractListModel):

    countChanged             : typing.ClassVar[Signal] = ... # countChanged()
    documentChanged          : typing.ClassVar[Signal] = ... # documentChanged()
    searchStringChanged      : typing.ClassVar[Signal] = ... # searchStringChanged()

    class Role(enum.Enum):

        Page                      = 0x100
        IndexOnPage               = 0x101
        Location                  = 0x102
        ContextBefore             = 0x103
        ContextAfter              = 0x104
        NRoles                    = 0x105


    @typing.overload
    def __init__(self, parent: PySide6.QtCore.QObject, /, *, document: PySide6.QtPdf.QPdfDocument | None = ..., searchString: str | None = ..., count: int | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, document: PySide6.QtPdf.QPdfDocument | None = ..., searchString: str | None = ..., count: int | None = ...) -> None: ...

    def count(self, /) -> int: ...
    def data(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, role: int, /) -> typing.Any: ...
    def document(self, /) -> PySide6.QtPdf.QPdfDocument: ...
    def resultAtIndex(self, index: int, /) -> PySide6.QtPdf.QPdfLink: ...
    def resultsOnPage(self, page: int, /) -> typing.List[PySide6.QtPdf.QPdfLink]: ...
    def roleNames(self, /) -> typing.Dict[int, PySide6.QtCore.QByteArray]: ...
    def rowCount(self, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> int: ...
    def searchString(self, /) -> str: ...
    def setDocument(self, document: PySide6.QtPdf.QPdfDocument, /) -> None: ...
    def setSearchString(self, searchString: str, /) -> None: ...
    def timerEvent(self, event: PySide6.QtCore.QTimerEvent, /) -> None: ...
    def updatePage(self, page: int, /) -> None: ...


class QPdfSelection(Shiboken.Object):

    def __init__(self, other: PySide6.QtPdf.QPdfSelection, /, *, valid: bool | None = ..., bounds: collections.abc.Sequence[PySide6.QtGui.QPolygonF] | None = ..., boundingRectangle: PySide6.QtCore.QRectF | None = ..., text: str | None = ..., startIndex: int | None = ..., endIndex: int | None = ...) -> None: ...

    def boundingRectangle(self, /) -> PySide6.QtCore.QRectF: ...
    def bounds(self, /) -> typing.List[PySide6.QtGui.QPolygonF]: ...
    def copyToClipboard(self, /, mode: PySide6.QtGui.QClipboard.Mode = ...) -> None: ...
    def endIndex(self, /) -> int: ...
    def isValid(self, /) -> bool: ...
    def startIndex(self, /) -> int: ...
    def swap(self, other: PySide6.QtPdf.QPdfSelection, /) -> None: ...
    def text(self, /) -> str: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtSvg, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtSvg`

import PySide6.QtSvg
import PySide6.QtCore
import PySide6.QtGui

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class QSvgGenerator(PySide6.QtGui.QPaintDevice):

    class SvgVersion(enum.Enum):

        SvgTiny12                 = 0x0
        Svg11                     = 0x1


    @typing.overload
    def __init__(self, version: PySide6.QtSvg.QSvgGenerator.SvgVersion, /, *, size: PySide6.QtCore.QSize | None = ..., viewBox: PySide6.QtCore.QRectF | None = ..., title: str | None = ..., description: str | None = ..., fileName: str | None = ..., outputDevice: PySide6.QtCore.QIODevice | None = ..., resolution: int | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, size: PySide6.QtCore.QSize | None = ..., viewBox: PySide6.QtCore.QRectF | None = ..., title: str | None = ..., description: str | None = ..., fileName: str | None = ..., outputDevice: PySide6.QtCore.QIODevice | None = ..., resolution: int | None = ...) -> None: ...

    def description(self, /) -> str: ...
    def fileName(self, /) -> str: ...
    def initPainter(self, arg__1: PySide6.QtGui.QPainter, /) -> None: ...
    def metric(self, metric: PySide6.QtGui.QPaintDevice.PaintDeviceMetric, /) -> int: ...
    def outputDevice(self, /) -> PySide6.QtCore.QIODevice: ...
    def paintEngine(self, /) -> PySide6.QtGui.QPaintEngine: ...
    def resolution(self, /) -> int: ...
    def setDescription(self, description: str, /) -> None: ...
    def setFileName(self, fileName: str, /) -> None: ...
    def setOutputDevice(self, outputDevice: PySide6.QtCore.QIODevice, /) -> None: ...
    def setResolution(self, dpi: int, /) -> None: ...
    def setSize(self, size: PySide6.QtCore.QSize, /) -> None: ...
    def setTitle(self, title: str, /) -> None: ...
    @typing.overload
    def setViewBox(self, viewBox: PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def setViewBox(self, viewBox: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    def size(self, /) -> PySide6.QtCore.QSize: ...
    def svgVersion(self, /) -> PySide6.QtSvg.QSvgGenerator.SvgVersion: ...
    def title(self, /) -> str: ...
    def viewBox(self, /) -> PySide6.QtCore.QRect: ...
    def viewBoxF(self, /) -> PySide6.QtCore.QRectF: ...


class QSvgRenderer(PySide6.QtCore.QObject):

    repaintNeeded            : typing.ClassVar[Signal] = ... # repaintNeeded()

    @typing.overload
    def __init__(self, contents: PySide6.QtCore.QXmlStreamReader, /, parent: PySide6.QtCore.QObject | None = ..., *, viewBox: PySide6.QtCore.QRectF | None = ..., framesPerSecond: int | None = ..., currentFrame: int | None = ..., aspectRatioMode: PySide6.QtCore.Qt.AspectRatioMode | None = ..., options: PySide6.QtSvg.QtSvg.Option | None = ..., animationEnabled: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, filename: str, /, parent: PySide6.QtCore.QObject | None = ..., *, viewBox: PySide6.QtCore.QRectF | None = ..., framesPerSecond: int | None = ..., currentFrame: int | None = ..., aspectRatioMode: PySide6.QtCore.Qt.AspectRatioMode | None = ..., options: PySide6.QtSvg.QtSvg.Option | None = ..., animationEnabled: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, viewBox: PySide6.QtCore.QRectF | None = ..., framesPerSecond: int | None = ..., currentFrame: int | None = ..., aspectRatioMode: PySide6.QtCore.Qt.AspectRatioMode | None = ..., options: PySide6.QtSvg.QtSvg.Option | None = ..., animationEnabled: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, contents: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /, parent: PySide6.QtCore.QObject | None = ..., *, viewBox: PySide6.QtCore.QRectF | None = ..., framesPerSecond: int | None = ..., currentFrame: int | None = ..., aspectRatioMode: PySide6.QtCore.Qt.AspectRatioMode | None = ..., options: PySide6.QtSvg.QtSvg.Option | None = ..., animationEnabled: bool | None = ...) -> None: ...

    def animated(self, /) -> bool: ...
    def animationDuration(self, /) -> int: ...
    def aspectRatioMode(self, /) -> PySide6.QtCore.Qt.AspectRatioMode: ...
    def boundsOnElement(self, id: str, /) -> PySide6.QtCore.QRectF: ...
    def currentFrame(self, /) -> int: ...
    def defaultSize(self, /) -> PySide6.QtCore.QSize: ...
    def elementExists(self, id: str, /) -> bool: ...
    def framesPerSecond(self, /) -> int: ...
    def isAnimationEnabled(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    @typing.overload
    def load(self, contents: PySide6.QtCore.QXmlStreamReader, /) -> bool: ...
    @typing.overload
    def load(self, filename: str, /) -> bool: ...
    @typing.overload
    def load(self, contents: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> bool: ...
    def options(self, /) -> PySide6.QtSvg.QtSvg.Option: ...
    @typing.overload
    def render(self, p: PySide6.QtGui.QPainter, /) -> None: ...
    @typing.overload
    def render(self, p: PySide6.QtGui.QPainter, elementId: str, /, bounds: PySide6.QtCore.QRectF | PySide6.QtCore.QRect = ...) -> None: ...
    @typing.overload
    def render(self, p: PySide6.QtGui.QPainter, bounds: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    def setAnimationEnabled(self, enable: bool, /) -> None: ...
    def setAspectRatioMode(self, mode: PySide6.QtCore.Qt.AspectRatioMode, /) -> None: ...
    def setCurrentFrame(self, arg__1: int, /) -> None: ...
    @staticmethod
    def setDefaultOptions(flags: PySide6.QtSvg.QtSvg.Option, /) -> None: ...
    def setFramesPerSecond(self, num: int, /) -> None: ...
    def setOptions(self, flags: PySide6.QtSvg.QtSvg.Option, /) -> None: ...
    @typing.overload
    def setViewBox(self, viewbox: PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def setViewBox(self, viewbox: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    def transformForElement(self, id: str, /) -> PySide6.QtGui.QTransform: ...
    def viewBox(self, /) -> PySide6.QtCore.QRect: ...
    def viewBoxF(self, /) -> PySide6.QtCore.QRectF: ...


class QtSvg(Shiboken.Object):

    class Option(enum.Flag):

        NoOption                  = 0x0
        Tiny12FeaturesOnly        = 0x1
        AssumeTrustedSource       = 0x2
        DisableSMILAnimations     = 0x10
        DisableCSSAnimations      = 0x20
        DisableAnimations         = 0xf0


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof
